import os
from PyPDF2 import PdfReader, PdfWriter

def analyze_pdf_page_sizes(pdf_path):
    reader = PdfReader(pdf_path)
    if len(reader.pages) == 0:
        return "Fail - PDF has no pages", []

    first_page = reader.pages[0]
    first_page_width = first_page.mediabox.width
    wide_pages = []

    for i, page in enumerate(reader.pages[1:], start=2):
        current_width = page.mediabox.width
        if current_width >= 2 * first_page_width:
            wide_pages.append(i - 1)  # PyPDF2 uses 0-based indexing

    if wide_pages:
        return f"Fail - Pages {', '.join(map(str, wide_pages))} have double (or more) the width of the first page", wide_pages
    return "Pass - No pages with double width found", []

def remove_wide_pages(pdf_path, wide_pages):
    reader = PdfReader(pdf_path)
    writer = PdfWriter()

    for i, page in enumerate(reader.pages):
        if i not in wide_pages:
            writer.add_page(page)

    with open(pdf_path, 'wb') as f:
        writer.write(f)

def process_pdfs_in_folders():
    script_directory = os.path.dirname(os.path.abspath(__file__))
    folders = [f for f in os.listdir(script_directory) 
               if os.path.isdir(os.path.join(script_directory, f)) and f != '__pycache__']

    if not folders:
        print("No adjacent folders found.")
        return

    print(f"Found {len(folders)} adjacent folders: {', '.join(folders)}")

    failed_pdfs = []

    for folder in folders:
        folder_path = os.path.join(script_directory, folder)
        print(f"\nProcessing folder: {folder}")
        pdf_files = [f for f in os.listdir(folder_path) if f.lower().endswith('.pdf')]

        if not pdf_files:
            print(f"No PDF files found in {folder}")
            continue

        print(f"Found {len(pdf_files)} PDF files. Analyzing...")

        for pdf_file in pdf_files:
            pdf_path = os.path.join(folder_path, pdf_file)
            result, wide_pages = analyze_pdf_page_sizes(pdf_path)
            print(f"{pdf_file}: {result}")
            
            if result.startswith("Fail"):
                failed_pdfs.append((os.path.join(folder, pdf_file), wide_pages))

    print("\nAll folders have been processed.")

    if failed_pdfs:
        print(f"\n{len(failed_pdfs)} PDFs failed the double width check.")
        user_input = input("Do you want to delete the wide pages from these PDFs? (yes/no): ").strip().lower()
        
        if user_input == 'yes':
            for pdf_path, wide_pages in failed_pdfs:
                full_path = os.path.join(script_directory, pdf_path)
                remove_wide_pages(full_path, wide_pages)
                print(f"Processed: {pdf_path}")
            print("\nAll wide pages have been removed from the failed PDFs.")
        else:
            print("\nNo changes were made to the PDFs.")

        with open('fail.txt', 'w') as f:
            for pdf, _ in failed_pdfs:
                f.write(f"{pdf}\n")
        print(f"\nList of originally failed PDFs has been recorded in fail.txt")
    else:
        print("\nNo PDFs failed the double width check.")

# Run the script
if __name__ == "__main__":
    process_pdfs_in_folders()